@@ -1,13 +1,41 @@
 # Run test ie with: rspec spec/unit/provider/nova_spec.rb
 
 require 'puppet/util/inifile'
+require 'puppet/provider/openstack'
+require 'puppet/provider/openstack/auth'
+require 'puppet/provider/openstack/credentials'
 
-class Puppet::Provider::Nova < Puppet::Provider
+class Puppet::Provider::Nova < Puppet::Provider::Openstack
+
+  extend Puppet::Provider::Openstack::Auth
+
+  def self.request(service, action, properties=nil)
+    begin
+      super
+    rescue Puppet::Error::OpenstackAuthInputError => error
+      nova_request(service, action, error, properties)
+    end
+  end
+
+  def self.nova_request(service, action, error, properties=nil)
+    properties ||= []
+    @credentials.username = nova_credentials['username']
+    @credentials.password = nova_credentials['password']
+    @credentials.project_name = nova_credentials['project_name']
+    @credentials.auth_url = auth_endpoint
+    if @credentials.version == '3'
+      @credentials.user_domain_name = nova_credentials['user_domain_name']
+      @credentials.project_domain_name = nova_credentials['project_domain_name']
+    end
+    raise error unless @credentials.set?
+    Puppet::Provider::Openstack.request(service, action, properties, @credentials)
+  end
 
   def self.conf_filename
     '/etc/nova/nova.conf'
   end
 
+  # deprecated: method for old nova cli auth
   def self.withenv(hash, &block)
     saved = ENV.to_hash
     hash.each do |name, val|
@@ -39,8 +67,7 @@ class Puppet::Provider::Nova < Puppet::Provider
 
   def self.get_nova_credentials
     #needed keys for authentication
-    auth_keys = ['auth_host', 'auth_port', 'auth_protocol',
-                 'admin_tenant_name', 'admin_user', 'admin_password']
+    auth_keys = ['auth_uri', 'project_name', 'username', 'password']
     conf = nova_conf
     if conf and conf['keystone_authtoken'] and
         auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
@@ -49,6 +76,16 @@ class Puppet::Provider::Nova < Puppet::Provider
       if conf['neutron'] and conf['neutron']['region_name']
         creds['region_name'] = conf['neutron']['region_name'].strip
       end
+      if !conf['keystone_authtoken']['project_domain_name'].nil?
+        creds['project_domain_name'] = conf['keystone_authtoken']['project_domain_name'].strip
+      else
+        creds['project_domain_name'] = 'Default'
+      end
+      if !conf['keystone_authtoken']['user_domain_name'].nil?
+        creds['user_domain_name'] = conf['keystone_authtoken']['user_domain_name'].strip
+      else
+        creds['user_domain_name'] = 'Default'
+      end
       return creds
     else
       raise(Puppet::Error, "File: #{conf_filename} does not contain all " +
@@ -59,20 +96,21 @@ class Puppet::Provider::Nova < Puppet::Provider
 
   def self.get_auth_endpoint
     q = nova_credentials
-    "#{q['auth_protocol']}://#{q['auth_host']}:#{q['auth_port']}/v2.0/"
+    "#{q['auth_uri']}"
   end
 
   def self.auth_endpoint
     @auth_endpoint ||= get_auth_endpoint
   end
 
+  # deprecated: method for old nova cli auth
   def self.auth_nova(*args)
     q = nova_credentials
     authenv = {
-      :OS_AUTH_URL    => self.auth_endpoint,
-      :OS_USERNAME    => q['admin_user'],
-      :OS_TENANT_NAME => q['admin_tenant_name'],
-      :OS_PASSWORD    => q['admin_password']
+      :OS_AUTH_URL     => self.auth_endpoint,
+      :OS_USERNAME     => q['username'],
+      :OS_PROJECT_NAME => q['project_name'],
+      :OS_PASSWORD     => q['password']
     }
     if q.key?('region_name')
       authenv[:OS_REGION_NAME] = q['region_name']
@@ -94,6 +132,7 @@ class Puppet::Provider::Nova < Puppet::Provider
     end
   end
 
+  # deprecated: method for old nova cli auth
   def auth_nova(*args)
     self.class.auth_nova(args)
   end
@@ -113,6 +152,7 @@ class Puppet::Provider::Nova < Puppet::Provider
     end
   end
 
+  # deprecated: string to list for nova cli
   def self.str2list(s)
     #parse string
     if s.include? ","
@@ -121,12 +161,23 @@ class Puppet::Provider::Nova < Puppet::Provider
       else
         new = []
       end
-      s.split(",").each do |el|
-        ret = str2hash(el.strip())
-        if s.include? "="
-          new.update(ret)
-        else
-          new.push(ret)
+      if s =~ /^'.+'$/
+        s.split("', '").each do |el|
+          ret = str2hash(el.strip())
+          if s.include? "="
+            new.update(ret)
+          else
+            new.push(ret)
+          end
+        end
+      else
+        s.split(",").each do |el|
+          ret = str2hash(el.strip())
+          if s.include? "="
+            new.update(ret)
+          else
+            new.push(ret)
+          end
         end
       end
       return new
@@ -135,6 +186,7 @@ class Puppet::Provider::Nova < Puppet::Provider
     end
   end
 
+  # deprecated: nova cli to list
   def self.cliout2list(output)
     #don't proceed with empty output
     if output.empty?
@@ -165,66 +217,4 @@ class Puppet::Provider::Nova < Puppet::Provider
     return hash_list
   end
 
-  def self.nova_hosts
-    return @nova_hosts if @nova_hosts
-    cmd_output = auth_nova("host-list")
-    @nova_hosts = cliout2list(cmd_output)
-    @nova_hosts
-  end
-
-  def self.nova_get_host_by_name_and_type(host_name, service_type)
-    #find the host by name and service type
-    nova_hosts.each do |entry|
-      if entry["host_name"] == host_name
-        if entry["service"] == service_type
-            return entry["host_name"]
-        end
-      end
-    end
-    #name/service combo not found
-    return nil
-  end
-
-  def self.nova_aggregate_resources_ids(force_refresh=false)
-    # return the cached list unless requested
-    if not force_refresh
-      return @nova_aggregate_resources_ids if @nova_aggregate_resources_ids
-    end
-    #produce a list of hashes with Id=>Name pairs
-    lines = []
-    #run command
-    cmd_output = auth_nova("aggregate-list")
-    #parse output
-    @nova_aggregate_resources_ids = cliout2list(cmd_output)
-    #only interessted in Id and Name
-    @nova_aggregate_resources_ids.map{ |e| e.delete("Availability Zone")}
-    @nova_aggregate_resources_ids.map{ |e| e['Id'] = e['Id'].to_i}
-    @nova_aggregate_resources_ids
-  end
-
-  def self.nova_aggregate_resources_get_name_by_id(name, force_refresh=false)
-    #find the id by the given name
-    nova_aggregate_resources_ids(force_refresh).each do |entry|
-      if entry["Name"] == name
-        return entry["Id"]
-      end
-    end
-    #name not found
-    return nil
-  end
-
-  def self.nova_aggregate_resources_attr(id)
-    #run command to get details for given Id
-    cmd_output = auth_nova("aggregate-details", id)
-    list = cliout2list(cmd_output)[0]
-    if ! list["Hosts"].is_a?(Array)
-      if list["Hosts"] == ""
-        list["Hosts"] = []
-      else
-        list["Hosts"] = [ list["Hosts"] ]
-      end
-    end
-    return list
-  end
-
 end
