@@ -89,7 +89,7 @@ describe 'nova::compute::rbd' do
         ])
         is_expected.to contain_exec('get-or-set virsh secret').with(
           :command =>  '/usr/bin/virsh secret-define --file /etc/nova/secret.xml | /usr/bin/awk \'{print $2}\' | sed \'/^$/d\' > /etc/nova/virsh.secret',
-          :creates => '/etc/nova/virsh.secret',
+          :unless  => '/usr/bin/virsh secret-list | grep UUID',
           :require => ['File[/etc/nova/secret.xml]', 'Service[libvirt]'],
         )
         is_expected.to contain_exec('set-secret-value virsh').with(
@@ -140,7 +140,7 @@ describe 'nova::compute::rbd' do
         ])
         is_expected.to contain_exec('get-or-set virsh secret').with(
           :command =>  '/usr/bin/virsh secret-define --file /etc/nova/secret.xml | /usr/bin/awk \'{print $2}\' | sed \'/^$/d\' > /etc/nova/virsh.secret',
-          :creates => '/etc/nova/virsh.secret',
+          :unless  => '/usr/bin/virsh secret-list | grep UUID',
           :require => ['File[/etc/nova/secret.xml]', 'Service[libvirt]'],
         )
         is_expected.to contain_exec('set-secret-value virsh').with(
@@ -160,28 +160,24 @@ describe 'nova::compute::rbd' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :ceph_client_package => 'ceph' }
+        when 'RedHat'
+          { :ceph_client_package => 'ceph-common' }
+        end
+      end
+      it_configures 'nova compute rbd'
     end
-
-    let :platform_params do
-      { :ceph_client_package => 'ceph'}
-    end
-
-    it_configures 'nova compute rbd'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :ceph_client_package => 'ceph-common' }
-    end
-
-    it_configures 'nova compute rbd'
   end
 
 end
