@@ -20,8 +20,6 @@ describe 'nova::conductor' do
       :ensure    => 'running'
     )}
 
-    it { is_expected.to contain_nova_config('conductor/use_local').with_value('false') }
-
     context 'with manage_service as false' do
       let :params do
         { :enabled        => true,
@@ -75,30 +73,26 @@ describe 'nova::conductor' do
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :conductor_package_name => 'nova-conductor',
+            :conductor_service_name => 'nova-conductor' }
+        when 'RedHat'
+          { :conductor_package_name => 'openstack-nova-conductor',
+            :conductor_service_name => 'openstack-nova-conductor' }
+        end
+      end
+      it_configures 'nova-conductor'
     end
-
-    let :platform_params do
-      { :conductor_package_name => 'nova-conductor',
-        :conductor_service_name => 'nova-conductor' }
-    end
-
-    it_configures 'nova-conductor'
-  end
-
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :conductor_package_name => 'openstack-nova-conductor',
-        :conductor_service_name => 'openstack-nova-conductor' }
-    end
-
-    it_configures 'nova-conductor'
   end
 
 end
