@@ -9,6 +9,7 @@ describe 'nova::db' do
   shared_examples 'nova::db' do
 
     context 'with default parameters' do
+      it { is_expected.to_not contain_nova_config('database/db_max_retries') }
       it { is_expected.to_not contain_nova_config('database/connection') }
       it { is_expected.to_not contain_nova_config('database/slave_connection') }
       it { is_expected.to_not contain_nova_config('api_database/connection') }
@@ -29,6 +30,7 @@ describe 'nova::db' do
         )
       end
 
+      it { is_expected.to contain_nova_config('database/db_max_retries').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('database/connection').with_value('mysql+pymysql://user:pass@db/db1').with_secret(true) }
       it { is_expected.to contain_nova_config('database/slave_connection').with_value('mysql+pymysql://user:pass@slave/db1').with_secret(true) }
       it { is_expected.to contain_nova_config('api_database/connection').with_value('mysql+pymysql://user:pass@db/db2').with_secret(true) }
@@ -76,62 +78,58 @@ describe 'nova::db' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-        :operatingsystem => 'Debian',
-        :operatingsystemrelease => 'jessie',
-      })
-    end
+  shared_examples_for 'nova::db RedHat' do
+    context 'using pymysql driver' do
+      let :params do
+        { :database_connection   => 'mysql+pymysql://user:pass@db/db', }
+      end
 
-    it_configures 'nova::db'
+      it { is_expected.not_to contain_package('db_backend_package') }
+    end
+  end
+
+  shared_examples_for 'nova::db Debian' do
 
     context 'using pymysql driver' do
       let :params do
         { :database_connection   => 'mysql+pymysql://user:pass@db/db', }
       end
+
       it 'install the proper backend package' do
-        is_expected.to contain_package('nova-backend-package').with(
+        is_expected.to contain_package('db_backend_package').with(
           :ensure => 'present',
           :name   => 'python-pymysql',
-          :tag    => ['openstack', 'nova-package'],
+          :tag    => ['openstack'],
         )
       end
     end
 
     context 'with sqlite backend' do
       let :params do
-        { :database_connection     => 'sqlite:///var/lib/nova/nova.sqlite', }
+        { :database_connection => 'sqlite:///var/lib/nova/nova.sqlite', }
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('nova-backend-package').with(
+        is_expected.to contain_package('db_backend_package').with(
           :ensure => 'present',
           :name   => 'python-pysqlite2',
-          :tag    => ['openstack', 'nova-package'],
+          :tag    => ['openstack'],
         )
       end
-
     end
+
   end
 
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'RedHat',
-        :operatingsystemrelease => '7.1',
-      })
-    end
-
-    it_configures 'nova::db'
-
-    context 'using pymysql driver' do
-      let :params do
-        { :database_connection   => 'mysql+pymysql://user:pass@db/db', }
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
       end
 
-      it { is_expected.not_to contain_package('nova-backend-package') }
+      it_configures 'nova::db'
+      it_configures "nova::db #{facts[:osfamily]}"
     end
   end
 
