@@ -50,8 +50,10 @@ describe 'nova::serialproxy' do
 
   context 'on Ubuntu system' do
     let :facts do
-      { :osfamily        => 'Debian',
-        :operatingsystem => 'Ubuntu' }
+      @default_facts.merge({
+        :osfamily        => 'Debian',
+        :operatingsystem => 'Ubuntu'
+      })
     end
 
     let :platform_params do
@@ -64,8 +66,10 @@ describe 'nova::serialproxy' do
 
   context 'on Debian system' do
     let :facts do
-      { :osfamily        => 'Debian',
-        :operatingsystem => 'Debian' }
+     @default_facts.merge({
+       :osfamily        => 'Debian',
+        :operatingsystem => 'Debian'
+      })
     end
 
     let :platform_params do
@@ -78,7 +82,7 @@ describe 'nova::serialproxy' do
 
   context 'on Redhat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     let :platform_params do
