@@ -13,13 +13,8 @@ describe 'nova::vncproxy' do
           @default_facts.merge({ :osfamily => 'Debian' })
       end
 
-      it { is_expected.to contain_package('python-numpy').with(
-        :ensure => 'present',
-        :name   => 'python-numpy'
-      )}
-
-      it { is_expected.to contain_nova_config('DEFAULT/novncproxy_host').with(:value => '0.0.0.0') }
-      it { is_expected.to contain_nova_config('DEFAULT/novncproxy_port').with(:value => '6080') }
+      it { is_expected.to contain_nova_config('vnc/novncproxy_host').with(:value => '0.0.0.0') }
+      it { is_expected.to contain_nova_config('vnc/novncproxy_port').with(:value => '6080') }
       it { is_expected.to contain_nova_config('vnc/novncproxy_base_url').with(:value => 'http://0.0.0.0:6080/vnc_auto.html') }
 
       it { is_expected.to contain_package('nova-vncproxy').with(
@@ -96,11 +91,6 @@ describe 'nova::vncproxy' do
       @default_facts.merge({ :osfamily => 'Redhat' })
     end
 
-    it { is_expected.to contain_package('python-numpy').with(
-      :name   => 'numpy',
-      :ensure => 'present'
-    )}
-
     it { is_expected.to compile.with_all_deps }
 
   end
